
% Generate 2-dimensional random data in two classes. 
% Class one will be two spherical Gaussian clusters,
% class two will consist of three spherical Gaussian clusters.
% Each data item will be a row in X
% Corresponding row in D will be the desired response

randn('state',3);
samples = 100; % total number of samples to generate

frac11 = 1; % define proportions of samples in each cluster
frac12 = 1; 
frac21 = 1;
frac22 = 3;
frac23 = 1;
fsum = frac11+frac12+frac21+frac22+frac23;

var11=3;    % define variance of each cluster
var12=2;
var21=2;
var22=1.5;
var23=2.5;

center11 = [-4, 1]; % define center of each cluster
center12 = [ 4, 4];
center21 = [-4,-4];
center22 = [-1, 1];
center23 = [ 5,-2];

% Generate class one
samples11= round(samples*frac11/fsum);
samples12= round(samples*frac12/fsum);
X1 = var11*randn(samples11,2) + ...
    repmat(center11, samples11,1); % move cluster to center11
X = var12*randn(samples12,2) + ...
    repmat(center12, samples12,1); 
X1 = [X; X1];

% Generate class two: three clusters
samples21=round(samples*frac21/fsum);
samples22=round(samples*frac22/fsum);
samples23=samples-samples22-samples21-samples12-samples11;
X2 = var21*randn(samples21,2) + ...
    repmat(center21, samples21,1); 
X = var22*randn(samples22,2) + ...
    repmat(center22, samples22,1); 
X2 = [X; X2];
X = var23*randn(samples23,2) + ...
    repmat(center23, samples23,1); 
X2 = [X; X2];

% plot the samples
figure(1);clf;
plot(X1(:,1),X1(:,2),'ro'); hold on;
plot(X2(:,1),X2(:,2),'bx'); hold off;
axis([-10,10,-10,10]);

% construct the data matrix including a constant column
samples1 = samples11+samples12;
samples2 = samples-samples1;
X = [ones(samples,1), [X1;X2]]; % bias added as a constant column
D = [ones(samples1,1),   zeros(samples1,1); % desired responses
     zeros(samples-samples1,1), ones(samples-samples1,1)];

% shuffle data in random order so that we can just loop
% over X and it looks like random samples from the distribution
r = randperm(samples);
X = X(r,:);
D = D(r,:);

